The CPLD i2c address is changed to 0x38

The earlier address 0x70 had got conflicts with another device.

Tested:
 Run the below command in MFG mode:
 ipmitool raw 0x32 0x91

Signed-off-by: Yong Li <yong.b.li@linux.intel.com>
Change-Id: I84ad367544eb977dbd8e7e700a53af4b48f6fe89
diff --git a/src/manufacturingcommands.cpp b/src/manufacturingcommands.cpp
index f2f8a58..c554afa 100644
--- a/src/manufacturingcommands.cpp
+++ b/src/manufacturingcommands.cpp
@@ -961,10 +961,10 @@
 
 ipmi::RspType<> clearCMOS()
 {
     // There is an i2c device on bus 4, the slave address is 0x70. Based on the
     // spec, writing 0x1 to address 0x60 on this device, will trigger the clear
     // CMOS action.
-    constexpr uint8_t slaveAddr = 0x70;
+    constexpr uint8_t slaveAddr = 0x38;
     std::string i2cBus = "/dev/i2c-4";
     std::vector<uint8_t> writeData = {0x60, 0x1};
     std::vector<uint8_t> readBuf(0);
@@ -961,10 +961,10 @@
 ipmi::RspType<> clearCMOS()
 {
-    // There is an i2c device on bus 4, the slave address is 0x70. Based on the
+    // There is an i2c device on bus 4, the slave address is 0x38. Based on the
     // spec, writing 0x1 to address 0x60 on this device, will trigger the clear
     // CMOS action.